import type { BannerView } from '../surfaces/banner';
import type { ContextualBarView } from '../surfaces/contextualBar';
import type { ModalView } from '../surfaces/modal';
type OpenModalServerInteraction = {
    type: 'modal.open';
    triggerId: string;
    appId: string;
    view: ModalView;
};
type UpdateModalServerInteraction = {
    type: 'modal.update';
    triggerId: string;
    appId: string;
    view: ModalView;
};
type CloseModalServerInteraction = {
    type: 'modal.close';
    triggerId: string;
    appId: string;
};
type OpenBannerServerInteraction = {
    type: 'banner.open';
    triggerId: string;
    appId: string;
} & BannerView;
type UpdateBannerServerInteraction = {
    type: 'banner.update';
    triggerId: string;
    appId: string;
    view: BannerView;
};
type CloseBannerServerInteraction = {
    type: 'banner.close';
    triggerId: string;
    appId: string;
    viewId: BannerView['viewId'];
};
type OpenContextualBarServerInteraction = {
    type: 'contextual_bar.open';
    triggerId: string;
    appId: string;
    view: ContextualBarView;
};
type UpdateContextualBarServerInteraction = {
    type: 'contextual_bar.update';
    triggerId: string;
    appId: string;
    view: ContextualBarView;
};
type CloseContextualBarServerInteraction = {
    type: 'contextual_bar.close';
    triggerId: string;
    appId: string;
    view: ContextualBarView;
};
type ReportErrorsServerInteraction = {
    type: 'errors';
    triggerId: string;
    appId: string;
    viewId: ModalView['id'] | BannerView['viewId'] | ContextualBarView['id'];
    errors: {
        [field: string]: string;
    }[];
};
export type ServerInteraction = OpenModalServerInteraction | UpdateModalServerInteraction | CloseModalServerInteraction | OpenBannerServerInteraction | UpdateBannerServerInteraction | CloseBannerServerInteraction | OpenContextualBarServerInteraction | UpdateContextualBarServerInteraction | CloseContextualBarServerInteraction | ReportErrorsServerInteraction;
export declare const isOpenModalServerInteraction: (input: unknown) => input is OpenModalServerInteraction;
export declare const isUpdateModalServerInteraction: (input: unknown) => input is UpdateModalServerInteraction;
export declare const isCloseModalServerInteraction: (input: unknown) => input is CloseModalServerInteraction;
export declare const isOpenBannerServerInteraction: (input: unknown) => input is OpenBannerServerInteraction;
export declare const isUpdateBannerServerInteraction: (input: unknown) => input is UpdateBannerServerInteraction;
export declare const isCloseBannerServerInteraction: (input: unknown) => input is CloseBannerServerInteraction;
export declare const isOpenContextualBarServerInteraction: (input: unknown) => input is OpenContextualBarServerInteraction;
export declare const isUpdateContextualBarServerInteraction: (input: unknown) => input is UpdateContextualBarServerInteraction;
export declare const isCloseContextualBarServerInteraction: (input: unknown) => input is CloseContextualBarServerInteraction;
export declare const isReportErrorsServerInteraction: (input: unknown) => input is ReportErrorsServerInteraction;
export declare const isServerInteraction: (input: unknown) => input is ServerInteraction;
export {};
//# sourceMappingURL=ServerInteraction.d.ts.map